within_gap_fill_horizon

Function within_gap_fill_horizon 

pub(crate) fn within_gap_fill_horizon(view: u64, watermark: u64) -> bool
Whether the height gap directly below the leaf at view can still be filled by a late decide: the missing view (at most view - 1) must be within DECIDE_GAP_FILL_HORIZON of watermark, the newest persisted decide.